package com.jiuqi.mde;

import java.util.ArrayList;
import java.util.Hashtable;

/* loaded from: com_jiuqi_mde.jar:com/jiuqi/mde/MDEFieldSet.class */
public final class MDEFieldSet {
    private ArrayList fields = new ArrayList(128);
    private Hashtable search = new Hashtable(127);
    private Hashtable indexs = null;

    public int size() {
        return this.fields.size();
    }

    public void setCapacity(int capacity) {
        this.fields = new ArrayList(capacity);
        this.search = new Hashtable(capacity);
    }

    public MDEField get(int index) {
        return (MDEField) this.fields.get(index);
    }

    public void clear() {
        this.fields.clear();
        this.search.clear();
        this.indexs = null;
    }

    public void add(MDEField field) {
        this.indexs = null;
        if (!this.search.containsKey(field.name)) {
            this.fields.add(field);
            this.search.put(field.name, field);
        }
    }

    public void add(int index, MDEField field) {
        this.indexs = null;
        if (!this.search.containsKey(field.name)) {
            this.fields.add(index, field);
            this.search.put(field.name, field);
        }
    }

    public void add(MDEFieldSet fields) {
        for (int i = 0; i < fields.size(); i++) {
            add(fields.get(i));
        }
    }

    public void remove(int index) {
        this.indexs = null;
        MDEField field = (MDEField) this.fields.get(index);
        this.search.remove(field.name);
        this.fields.remove(index);
    }

    public void remove(MDEField field) {
        this.indexs = null;
        this.fields.remove(field);
        this.search.remove(field.name);
    }

    public MDEField find(String name) {
        return (MDEField) this.search.get(name);
    }

    public int indexOf(MDEField field) {
        Integer index = (Integer) this.indexs.get(field.fieldName);
        if (index == null) {
            return -1;
        }
        return index.intValue();
    }

    public int indexOfFieldName(String fieldName) {
        Integer index = (Integer) this.indexs.get(fieldName);
        if (index == null) {
            return -1;
        }
        return index.intValue();
    }

    public MDEField findByFieldName(String fieldName) {
        Integer index = (Integer) this.indexs.get(fieldName);
        if (index == null) {
            return null;
        }
        return (MDEField) this.fields.get(index.intValue());
    }

    public void complete() {
        if (this.indexs == null) {
            sortByFieldName();
            this.indexs = new Hashtable();
            this.indexs.clear();
            for (int i = 0; i < this.fields.size(); i++) {
                MDEField field = (MDEField) this.fields.get(i);
                this.indexs.put(field.fieldName, new Integer(i));
            }
        }
    }

    private void sortByFieldName() {
        for (int i = 1; i < this.fields.size(); i++) {
            MDEField field = (MDEField) this.fields.get(i);
            int start = 0;
            int stop = i - 1;
            while (true) {
                if (start > stop) {
                    break;
                }
                int middle = (start + stop) >> 1;
                int flag = field.fieldName.compareTo(((MDEField) this.fields.get(middle)).fieldName);
                if (flag > 0) {
                    start = middle + 1;
                } else if (flag < 0) {
                    stop = middle - 1;
                } else {
                    start = middle;
                    break;
                }
            }
            if (start < i) {
                for (int k = i; k > start; k--) {
                    this.fields.set(k, this.fields.get(k - 1));
                }
                this.fields.set(start, field);
            }
        }
    }

    public Object clone() {
        MDEFieldSet result = new MDEFieldSet();
        result.add(this);
        return result;
    }
}
